茶馆 (豆瓣)
Description: 茶馆电影简介和剧情介绍,茶馆影评、图片、预告片、影讯、论坛、在线购票
Keywords: 茶馆,茶馆,茶馆影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.173豆瓣电影Top250

# 茶馆 (1982)

导演: 谢添
编剧: 老舍
主演: 于是之 / 郑榕 / 蓝天野 / 英若诚 / 黄宗洛 / 童超 / 金昭 / 林连昆 / 牛星丽 / 谭宗尧 / 童弟 / 吴淑昆 / 胡宗温 / 程中 / 李大千 / 李源 / 李翔 / 张瞳 / 任宝贤 / 尚丽娟 / 米铁增 / 田春奎 / 冯增祥 / 雷飞 / 林东升 / 孟瑾 / 孙峻峰 / 平原 / 曹世骧 / 王大年 / 王淑华 / 张华 / 丁海涛 / 朱旭 / 孙敬修 / 曹孟浪 / 何康理
类型: 剧情 / 历史
制片国家/地区: 中国大陆
语言: 汉语普通话
上映日期: 1982(中国大陆)
片长: 118分钟
又名: The Teahouse
IMDb: tt1395030
豆瓣评分
引用
9.5
121794人评价
5星
80.0%
4星
17.5%
3星
2.3%
2星
0.2%
1星
0.1%
好于 99% 历史片
好于 99% 剧情片
想看 看过
评价:
推荐

## 茶馆的剧情简介 · · · · · ·

世纪之交，古老的中国正迎来前所未有的巨大变革。老态龙钟的大清王朝摇摇欲坠，六君子的鲜血无法阻止历史车轮的滚动，老北京城的上空风云变幻，波谲云诡。王利发（于是之 饰），北京城内裕泰茶馆的年轻掌柜。他谨记父亲的教诲，体面周全地迎送四方宾客。小小的茶馆内，三教九流各色人等穿梭于此：提笼架鸟哀叹时运的松二爷（黄宗洛 饰）；慨叹国之将亡的刚毅满人常四爷（郑榕 饰）；一心谋求实业救国的秦仲义（蓝天野 饰）；丧尽天良买卖人口的刘麻子（英若诚 饰）；打算娶老婆的庞太监（童超 饰）……你方唱罢我登场，小小茶馆之内演尽世间的沧桑与凄凉……
本片根据老舍同名原著改编，并1983年第3届中国电影金鸡奖特别奖、文化部1982年优秀影片奖特别奖。 ©豆瓣

## 茶馆的演职员 · · · · · · ( 全部 61 )

- 谢添 导演
- 焦菊隐 原舞台导演
- 于是之 饰 王利发
- 郑榕 饰 常四爷
- 蓝天野 饰 秦仲义
- 英若诚 饰 刘麻子、小刘麻子

## 茶馆的图片 · · · · · · ( 添加视频评论 | 图片441 · 添加 )

## 茶馆的获奖情况 · · · · · · ( 全部 )

- 第3届中国电影金鸡奖
- 评委会特别奖 特别影片奖

## 喜欢这部电影的人也喜欢 · · · · · ·

  骆驼祥子

  无言的山丘

  我这一辈子

  末代皇帝

  祝福

  荆轲刺秦王

  阿Q正传

  雷雨

  横空出世

  影武者

我要写短评

## 茶馆的短评 · · · · · · ( 全部 34892 条 )

热门 / 最新 / 好友

### 3325 有用 康报虹 看过 2017-07-31 21:58:12

①莫谈国事。 ②这大清国是药丸啊！ ③改良改良，越改越凉。 ④我爱我们的国啊！可谁爱我呀？ ⑤有钱就得吃喝嫖赌，胡作非为，千万别做好事。 ⑥大英帝国的烟，日本的“白面儿”，两大强国侍候着我一个人，这点福气还小吗？ ⑦你们就找吧，可着全世界地找，你们还能找着这么混蛋的政府吗？

### 2511 有用 少年 遊 看过 2010-07-21 20:40:13

“我看这大清要亡国啊”。

### 2066 有用 大熊猫 看过 2010-06-27 02:32:04

芸芸众生，人间百态。 经典台词：我爱咱们的国呀，可是谁爱我。

### 1139 有用 毛毛毛读作cuì 看过 2010-06-19 17:32:23

管他什么时代，原来丑陋的现实都是一样的 ps:京味十足啊，那才叫演戏!!!看演员每一个比一个精彩，配角也不例外，和现在的国产电影相比，差距显而易见!!!

### 727 有用 桃桃林林 看过 2012-07-12 20:50:49

“打一个学生，五毛现大洋”这也算认主归宗了。片子拍得很话剧腔，不过味道还是很好，演得也好，有滋有味。秦二爷最后那段自白，现在听着还是有些伤感。

> 更多短评 34892条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 茶馆的影评 · · · · · · ( 全部 379 条 )

热门 / 最新 / 好友
新西兰孙小社 2011-02-16 22:47:28

## 老戏骨是不死的魂儿~

如同老舍先生原著的剧本一样，这部电影是你错过了，就会后悔终生的佳作。 原作茶馆的剧本所获得美誉不啻多提。茶馆，就像工业革命时期英国人常去的coffee house，不仅仅是一个供大家休闲品茶的店面，更是一个在网络还没有诞生，不同信息汇杂交融的讲堂；政策的革新，国家的兴... (展开)
755 18 119回应 收起
mob 2010-01-25 11:57:00

## 焦版《茶馆》，一个“民族”的《茶馆》

一个淫雨霏霏的下午，我看完了焦菊隐先生导演的话剧《茶馆》。 很早之前的时候读过老舍先生的剧本《茶馆》。先生的编剧着实不落窠臼。从一个小小茶馆的角度来看社会，把上世纪50年的中国史横向切出三块薄片，放在舞台的凸境下透视。登台的三代、70多个人物，构成世态风俗图卷，... (展开)
168 5 13回应 收起
Aloysius 2018-09-09 17:59:44

## 经典台词摘录

这篇影评可能有剧透

1、咱还是莫谈国事。 2、要抖威风，跟洋人干去，洋人厉害。 3、咱大清国有的是金山银山，永远流不完。 4、我要不给他帮忙，他兴许还找不着买主呢？ 5、在街面上办事，人缘最要紧。 6、我看呐，这大清国是要完呐！ 7、告诉您，谁敢改祖宗的章程，谁就得掉脑袋！ 8、我爱大清国，... (展开)
133 17回应 收起
Krabat 2017-03-26 18:39:53

## 大清完了，党国去了台湾，可《茶馆》还在

开茶馆莫谈国事的王利发 开工厂实业救国的秦二爷 卖蔬菜自食其力的常四爷 喜来宝戏谑世事的大傻杨 坑蒙拐骗丧天良的骗子大小刘麻子唐铁嘴 敲诈勒索不干事的公差大小吴恩子宋祥子 为虎作伥欺软怕硬的社会流氓大小二德子 官匪勾结强取豪夺的制度烂瘡庞太监沈处长 喜欢逗蛐蛐儿遛... (展开)
92 4 49回应 收起
toyman_28 2007-12-10 10:39:00

## 茶馆-历史变迁

旧时代“莫谈国事”的裕泰茶馆却一派繁荣景象：提笼架鸟、算命卜卦、卖古玩玉器、 玩蝈蝈蟋蟀者无所不有，茶桌上的人们聊天、侃侃大山，鱼龙混杂、三教九流都相约在此地见面、办事。一个大茶馆折射一个小社会，不免让我想到《Friends》中的六个人常常休息和聊天、聚会的场所... (展开)
79 9 8回应 收起
傻不傻666 2017-07-14 21:38:15

## 生如泡影

“一切有为法，如梦幻泡影，如雾亦如电，应作如是观”　　　　几天前在国家电影资料中心看完，10元钱，喜欢那悠闲老片的感觉。看完但觉大厦崩塌，天平失衡，嘴吐苦水，生如泡影。20年、20年的时间片段，各色人物，起起伏伏，都落了个恍如一梦的感慨。　　　　于是之扮演的王掌... (展开)
49 1 6回应 收起
田废久必生 2019-03-27 23:54:16

## 作为电影的《茶馆》

大家一向认为因为是话剧改编，此片舞台痕迹太重而不太“电影”。此番重看，却发现《茶馆》的电影化程度很高。 以舞台剧为基础，人物的站位调度都是定好的，环境空间上没有什么文章可做，如此绚丽的对白之下也没必要花哨地剪辑，电影化的任务其实只是通过电影的手法去把这个故事... (展开)
41 1 4回应 收起
李玩 2015-07-31 12:15:36

## 茶馆还在

这篇影评可能有剧透

我爱国的啊，可是，谁爱我啊？良民如掌柜、实业救国秦二爷、耿直满旗常四爷几个，总是盼着、盼着，希望盼来一个讲理的社会，六十年过去，发现，社会还是这么个社会，人还是这帮人，只是子承父业了，恶还是恶，奸诈还是这般狡猾，恶人一如惯常那样的油腔滑调、坑蒙拐骗，... (展开)
36 0回应 收起
公子文 2019-09-03 01:14:45

## 愿人性不泯，一辈子坦坦荡荡

这篇影评可能有剧透

想找一部电影看看，并且是国产电影，就随便搜了搜。不知道怎么搜到了这部《茶馆》，还是一部82年的老电影。比我都大了10岁。但是电影本身所给我的价值，却远非10年的时间可以磨灭的。 一间小茶馆，百味人生在其中。小小茶馆经历了清-军阀-民国-解放前。曾经鼎鼎大名的 裕泰茶馆... (展开)
16 1回应 收起
strayer 2011-01-22 17:31:43

## 泛起的沉渣，残缺的历史

从光绪年间到抗战胜利，历经皇帝三个、总统无数，洋人侵占、地方割据，大家轮流坐庄，宏大叙事向我们展示了历史风起云涌的一面。 　　而另一面，则是不变的场景，甚至不变的人物——老子死了小子上，青出于蓝胜于蓝——每个人都改换了门庭、装束（连茶馆也要“改良”），却... (展开)
11 1回应 收起

> 更多影评 379篇

添加新讨论

## 讨论区 · · · · · ·

这年头连陈小艺都能混进人艺, 可以想象现在有多糟... | 来自goslar6403 | 8 回应 | 2022-11-23 01:12:28
茶馆进top250了，实至名归 | 来自特种兵王 | 12 回应 | 2022-11-18 16:39:34
大写的尴尬 | 来自憨憨 | 12 回应 | 2022-11-11 04:13:16
越改越凉的改良 | 来自接过 | 1 回应 | 2022-11-09 00:34:52
还是得当公务员 | 来自趁早 | 3 回应 | 2022-11-07 01:57:40

> 去这部影片的讨论区（全部129条）

## 关于《茶馆》的问题 · · · · · · ( 全部6个 )

- 所以结局是王掌柜自杀了？ 4人回答
- 谁有带字幕的资源或者字幕也行？ 8人回答

> 全部6个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看
- 西瓜视频 免费观看
- 1905电影网 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(2/3) (影志)
- 中文电影250强总榜（1905——2012） (东方快车)
- 《看电影》杂志中文电影100强 (东方快车)
- 电影网华语电影在线地址 (桃桃林林)

## 谁在看这部电影 · · · · · ·

- 南望
  刚刚 看过
- 槐序
  刚刚 想看
- 一只小柑橘
  4分钟前 看过

187385人看过 / 103923人想看

订阅茶馆的评论:
feed: rss 2.0